//
// Rain via texture bombing
//
// Author: Alex V. Boreskoff
//


varying	vec4	vertex;

uniform	float		time;
uniform	sampler2D	randomMap;
uniform sampler2D	decalMap;
uniform sampler2D	glyphMap;

void main (void)
{
	const	float	scale     = 0.61234;

											// get decal color
	vec4	decalColor = texture2D ( decalMap, gl_TexCoord [0].xy );

											// get time cell offset
	vec3	cell0 = floor ( vertex.xyz * scale );
	vec3	offs0 = vertex.xyz * scale - cell0;
	vec3	rnd0  = texture2D ( randomMap, offs0.xy ).rgb;

											// offset time with cell0
	float	timeCell = floor ( time * 0.2 + rnd0.x );
	float	timeOffs = time * 0.2 - timeCell;

											// get cell no based on 3D-coordinates
	vec3	tex      = vertex.xyz * scale + vec3 ( timeCell * 0.5 );
	vec3	cell     = floor ( tex );
	vec3	offs     = tex - cell;
	vec3	rndOffs  = cell / scale;
	vec4	colorSum = vec4 ( 0.0 );

	for ( int i = 0; i < 2; i++ )
	{
		vec2	rndTex = rndOffs.xy + 0.1* rndOffs.zx + 0.3*rndOffs.yz;
		vec3	rnd    = texture2D ( randomMap, rndTex ).rgb;
		vec3	center = vec3 ( 0.2 ) + 0.6 * rnd;
		float	radius = 0.4 * fract ( 1.0 * ( timeOffs + rndOffs.x ) );

		if ( abs ( length ( center - offs ) - radius ) < 0.015 )					// place a bomb
			colorSum += vec4 ( 1.0 ) * ( 1.0 - radius / 0.7 );

		rndOffs += vec3 ( 0.345, 0.386, 0.773 );
	}

	gl_FragColor   = decalColor + colorSum;
	gl_FragColor.a = 1.0;
}
